@@ -1,7 +1,5 @@
 #pragma once
 
-#include <tins/tins.h>
-
 #include <filesystem>
 #include <fstream>
 #include <optional>
@@ -16,11 +14,12 @@ namespace caracal::Prober {
 
 /// Configuration of the prober.
 struct Config {
+  uint16_t caracal_id = get_default_id();
   uint64_t n_packets = 1;
   uint64_t probing_rate = 100;
   uint64_t sniffer_wait_time = 5;
-  Tins::NetworkInterface interface =
-      Tins::NetworkInterface::default_interface();
+  bool integrity_check = true;
+  std::string interface = get_default_interface();
   string rate_limiting_method = "auto";
   optional<uint64_t> max_probes;
   optional<fs::path> output_file_csv;
@@ -31,21 +30,29 @@ struct Config {
   optional<int> filter_max_ttl;
   optional<string> meta_round;
 
-  void set_output_file_csv(const fs::path& p);
+  static uint16_t get_default_id();
 
-  void set_output_file_pcap(const fs::path& p);
+  static std::string get_default_interface();
+
+  void set_caracal_id(int id);
+
+  void set_n_packets(int count);
 
   void set_probing_rate(int rate);
 
-  void set_interface(const string& s);
-
   void set_sniffer_wait_time(int seconds);
 
+  void set_integrity_check(bool check);
+
+  void set_interface(const string& s);
+
   void set_rate_limiting_method(const string& s);
 
   void set_max_probes(uint64_t count);
 
-  void set_n_packets(int count);
+  void set_output_file_csv(const fs::path& p);
+
+  void set_output_file_pcap(const fs::path& p);
 
   void set_prefix_excl_file(const fs::path& p);
 
