@@ -11,6 +11,7 @@ namespace fs = std::filesystem;
 namespace caracal::Reader {
 
 Statistics::Sniffer read(const fs::path& input_file,
-                         const fs::path& output_file, const std::string& round);
+                         const fs::path& output_file, const std::string& round,
+                         uint16_t caracal_id, bool integrity_check);
 
 }  // namespace caracal::Reader
