@@ -1,7 +1,11 @@
 #include <spdlog/fmt/ostr.h>
 #include <spdlog/spdlog.h>
 
+#include <boost/iostreams/device/file.hpp>
+#include <boost/iostreams/filter/zstd.hpp>
+#include <boost/iostreams/filtering_stream.hpp>
 #include <caracal/lpm.hpp>
+#include <caracal/pretty.hpp>
 #include <caracal/probe.hpp>
 #include <caracal/prober.hpp>
 #include <caracal/prober_config.hpp>
@@ -15,6 +19,7 @@
 
 namespace caracal::Prober {
 
+namespace io = boost::iostreams;
 using std::chrono::milliseconds;
 
 // NOTE: Should we expose this as a parameter?
@@ -55,6 +60,7 @@ ProbingStatistics probe(const Config& config, Iterator& it) {
     spdlog::info(rl.statistics());
     spdlog::info(stats);
     spdlog::info(sniffer.statistics());
+    spdlog::info(sniffer.pcap_statistics());
   };
 
   // Log statistics every 5 seconds
@@ -164,8 +170,13 @@ ProbingStatistics probe(const Config& config, const fs::path& p) {
   if (!fs::exists(p)) {
     throw std::invalid_argument(p.string() + " does not exists");
   }
+  io::filtering_stream<io::input> inp;
+  if (p.extension() == ".zst") {
+    inp.push(io::zstd_decompressor());
+  }
   std::ifstream ifs{p};
-  return probe(config, ifs);
+  inp.push(ifs);
+  return probe(config, inp);
 }
 
 }  // namespace caracal::Prober
